@@ -216,6 +216,10 @@ class CacheWorkspace:
             self.expire_in_days), '-c', 'temporary_files')
         out, _ = process.communicate()
         self.name = out.strip().decode('utf-8')
+        assert Path(
+            self.name).exists(), 'Could not create cache workspace with id {} and path {}'.format(
+            self.id, self.name)
+        assert self.name.startswith('/'), 'Cache workspace did not return an absolute path but {}'.format(self.name)
 
     def __enter__(self) -> None:
         if self.name is None:
